[PATCH] ublox: add additional models to supported_modes_per_model

Matthew Starr mstarr at hedonline.com
Tue Jul 31 00:25:32 UTC 2018


Updated the models based on information from the u-blox website.
--
plugins/ublox/mm-modem-helpers-ublox.c | 13 +++++++++++--
 1 file changed, 11 insertions(+), 2 deletions(-)

diff --git a/plugins/ublox/mm-modem-helpers-ublox.c b/plugins/ublox/mm-modem-helpers-ublox.c
index ff1a8488..1c124d41 100644
--- a/plugins/ublox/mm-modem-helpers-ublox.c
+++ b/plugins/ublox/mm-modem-helpers-ublox.c
@@ -484,9 +484,18 @@ supported_modes_per_model (const gchar *model)
     MMModemMode all = (MM_MODEM_MODE_2G | MM_MODEM_MODE_3G | MM_MODEM_MODE_4G);
 
     if (model) {
-        /* Some TOBY-L2/MPCI-L2 devices don't support 2G */
-        if (g_str_equal (model, "TOBY-L201") || g_str_equal (model, "TOBY-L220") || g_str_equal (model, "MPCI-L201"))
+        /* Some TOBY-L2/TOBY-R2/MPCI-L2/LARA-R2 devices don't support 2G */
+        if (g_str_equal (model, "TOBY-L201") || g_str_equal (model, "TOBY-L220") || g_str_equal (model, "TOBY-R202") || g_str_equal (model, "MPCI-L201") || g_str_equal (model, "MPCI-L220") || g_str_equal (model, "LARA-R202") || g_str_equal (model, "LARA-R280"))
             all &= ~MM_MODEM_MODE_2G;
+        /* Some LARA-R2 devices don't support 3G */
+        if (g_str_equal (model, "LARA-R211"))
+            all &= ~MM_MODEM_MODE_3G;
+        /* Some LARA-R2 devices only support 4G */
+        else if (g_str_equal (model, "LARA-R203") || g_str_equal (model, "LARA-R204") || g_str_equal (model, "LARA-R220"))
+            all = MM_MODEM_MODE_4G;
+        /* None of the SARA-G devices support 3G or 4G */
+        else if (g_str_has_prefix (model, "SARA-G"))
+            all = MM_MODEM_MODE_2G;
         /* None of the LISA-U or SARA-U devices support 4G */
         else if (g_str_has_prefix (model, "LISA-U") || g_str_has_prefix (model, "SARA-U")) {
             all &= ~MM_MODEM_MODE_4G;
--
2.14.1


More information about the ModemManager-devel mailing list